container Package
=================

:mod:`container` Package
------------------------

.. automodule:: camelot.container
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`chartcontainer` Module
----------------------------

.. automodule:: camelot.container.chartcontainer
    :members:
    :undoc-members:
    :show-inheritance:

